==> panya-social-0.0.3.tar.gz: panya-social-0.0.3/setup.py <==
from setuptools import setup, find_packages

setup(
    name='panya-social',
    version='0.0.3',
    description='Panya social app.',
    long_description = open('README.rst', 'r').read() + open('AUTHORS.rst', 'r').read() + open('CHANGELOG.rst', 'r').read(),
    author='Praekelt Foundation',
    author_email='dev@praekelt.com',
    license='BSD',
    url='http://github.com/praekelt/panya-social',
    packages = find_packages(),
    dependency_links = [
        'http://github.com/praekelt/django-socialregistration/tarball/0.4.1.tokenstore.1#egg=django-socialregistration-0.4.1.tokenstore.1',
        'http://github.com/facebook/python-sdk/tarball/master#egg=facebook-python-sdk',
        'http://github.com/praekelt/django-activity-stream/tarball/master#egg=django-activity-stream-0.2.1.praekelt',
        'http://github.com/pinax/django-friends/tarball/master#egg=django-friends-0.2.dev1',
        'http://github.com/pinax/django-notification/tarball/master#egg=django-notification-0.2.0.dev2',
    ],
    install_requires = [
        'django-activity-stream==0.2.1.praekelt',
        'django-friends==0.2.dev1',
        'django-notification==0.2.0.dev2',
        'django-socialregistration==0.4.1.tokenstore.1',
        'facebook-python-sdk',
        'panya',
    ],
    include_package_data=True,
    classifiers = [
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    zip_safe=False,
)

==> panya-social-0.0.4.tar.gz: panya-social-0.0.4/setup.py <==
from setuptools import setup, find_packages

setup(
    name='panya-social',
    version='0.0.4',
    description='Panya social app.',
    long_description = open('README.rst', 'r').read() + open('AUTHORS.rst', 'r').read() + open('CHANGELOG.rst', 'r').read(),
    author='Praekelt Foundation',
    author_email='dev@praekelt.com',
    license='BSD',
    url='http://github.com/praekelt/panya-social',
    packages = find_packages(),
    dependency_links = [
        'http://github.com/praekelt/django-socialregistration/tarball/0.4.1.tokenstore.1#egg=django-socialregistration-0.4.1.tokenstore.1',
        'http://github.com/facebook/python-sdk/tarball/master#egg=facebook-python-sdk',
        'http://github.com/praekelt/django-activity-stream/tarball/master#egg=django-activity-stream-0.2.1.praekelt',
        'http://github.com/pinax/django-friends/tarball/master#egg=django-friends-0.2.dev1',
        'http://github.com/downloads/praekelt/public-eggs/django_notification-0.2.0.dev2-py2.6.egg=django-notification',
    ],
    install_requires = [
        'django-activity-stream==0.2.1.praekelt',
        'django-friends==0.2.dev1',
        'django-notification',
        'django-socialregistration==0.4.1.tokenstore.1',
        'facebook-python-sdk',
        'panya',
    ],
    include_package_data=True,
    classifiers = [
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    zip_safe=False,
)
